FallbackConfig class

Constructors

FallbackConfig(bool enabled, String defaultLanguage)
FallbackConfig.disabled()
Configuration that disables fallback behavior
factory
FallbackConfig.enabled(String defaultLanguage)
Configuration that enables fallback to a default language
factory

Properties

defaultLanguage String
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited