ValidationConfig class

Constructors

ValidationConfig.always()
Configuration that always accepts translations
factory
ValidationConfig.withExpected(int column, String expected)
Configuration that will check the value set in the validation column and compare it with the expected value
factory

Properties

column int?
final
expected String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited