ValidationConfig.withExpected constructor

ValidationConfig.withExpected(
  1. int column,
  2. String expected
)

Configuration that will check the value set in the validation column and compare it with the expected value

Implementation

factory ValidationConfig.withExpected(int column, String expected) =>
    ValidationConfig._(column, expected);