Validator class sealed

Class used to validate or invalidate a translation

Constructors

Validator.get(ValidationConfig config)
Method that returns a validator object matching the specified config
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(List<String?> row) bool
Abstract method called to validate or invalidate a worksheet row
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited