PlaceholderFormatter class

Class responsible for formatting text and creating placeholder characteristics

Constructors

PlaceholderFormatter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createCharacteristics(List<PlaceholderMatch> placeholders) List<PlaceholderCharac>?
formatText(String originalText, List<PlaceholderMatch> placeholders) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited