WordingParser class

Main parser class that coordinates the parsing process

Constructors

WordingParser({PlaceholderExtractor? placeholderExtractor, PlaceholderFormatter? placeholderFormatter})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String rawText) WordingEntry
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited