WordingEntry class

Class defining a translation value, with its placeholder specificities

Constructors

WordingEntry(String value, List<PlaceholderCharac>? placeholderCharacs)

Properties

hashCode int
The hash code for this object.
no setterinherited
placeholderCharacs List<PlaceholderCharac>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited