wording_processor/placeholder_mismatch_processor library

Classes

PlaceholderMismatchProcessor
A processor that checks for placeholder mismatches in the wordings It will log a warning for each placeholder mismatch (name or type) between languages