wording_processor/wording_processor_manager library

Classes

WordingProcessor
A processor that validates and processes wordings
WordingProcessorManager
Manages the processing and validation of wordings by running them through a series of WordingProcessors like checking for missing translations and placeholder mismatches