ValidationConfig.withExpected constructor
Configuration that will check the value set in the validation column and compare it with the expected value
Implementation
factory ValidationConfig.withExpected(int column, String expected) =>
ValidationConfig._(column, expected);