WordingConfig class
Constructors
-
WordingConfig(CredentialsConfig credentials, String sheetId, List<
String> sheetNames, String outputDir, int sheetStartIndex, int keyColumn, List<LanguageConfig> languages, FallbackConfig fallback, ValidationConfig validation, GenL10nConfig genL10n)
Properties
- credentials → CredentialsConfig
-
final
- fallback → FallbackConfig
-
final
- genL10n → GenL10nConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyColumn → int
-
final
-
languages
→ List<
LanguageConfig> -
final
- outputDir → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sheetId → String
-
final
-
sheetNames
→ List<
String> -
final
- sheetStartIndex → int
-
final
- validation → ValidationConfig
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited