WordingConfigLoader class
Interface for loading configuration from a file Main class that coordinates the configuration loading process
Constructors
- WordingConfigLoader({YamlParser? yamlParser, ConfigBuilder? configBuilder})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
loadConfiguration(
String configPath) → Future< WordingConfig> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited