menu
sync_wording package
documentation
wording_processor/placeholder_mismatch_processor.dart
wording_processor/placeholder_mismatch_processor.dart
dark_mode
light_mode
wording_processor/placeholder_mismatch_processor
library
Classes
PlaceholderMismatchProcessor
A processor that checks for placeholder mismatches in the wordings It will log a warning for each placeholder mismatch (name or type) between languages
sync_wording package
documentation
wording_processor/placeholder_mismatch_processor.dart
sync_wording
package
Libraries
config/wording_config
config/wording_config_loader
exporter/arb/arb_wording_exporter
exporter/arb/typed_placeholder_exporter
exporter/wording_exporter
google/google_auth
google/xlsx_drive
logger/logger
spreadsheet_converter/validator/validator
spreadsheet_converter/wording_parser
spreadsheet_converter/xlsx_converter/xlsx_converter
wording
wording_processor/missing_wording_processor
wording_processor/placeholder_mismatch_processor
wording_processor/wording_processor_manager
placeholder_mismatch_processor library